@@ -1,13 +1,18 @@
 package Pod::Elemental::Element::Pod5::Verbatim;
-our $VERSION = '0.092900';
+our $VERSION = '0.092901';
 
 
 use Moose;
-with 'Pod::Elemental::Paragraph';
+extends 'Pod::Elemental::Element::Generic::Text';
+with    'Pod::Elemental::Element::Pod5';
 # ABSTRACT: a POD verbatim element
 
 use namespace::autoclean;
 
+sub as_debug_string {
+  return '(Pod5 Verbatim)';
+}
+
 1;
 
 __END__
@@ -20,7 +25,7 @@ Pod::Elemental::Element::Pod5::Verbatim - a POD verbatim element
 
 =head1 VERSION
 
-version 0.092900
+version 0.092901
 
 =head1 AUTHOR
 
