@@ -1,5 +1,5 @@
 package Pod::Elemental::Node;
-our $VERSION = '0.092900';
+our $VERSION = '0.092901';
 
 
 use Moose::Role;
@@ -23,6 +23,19 @@ has children => (
   default    => sub { [] },
 );
 
+around as_debug_string => sub {
+  my ($orig, $self) = @_;
+
+  my $str = $self->$orig;
+
+  my @children = map { $_->as_debug_string } $self->children->flatten;
+  s/^/  /sgm for @children;
+
+  $str = join "\n", $str, @children;
+
+  return $str;
+};
+
 1;
 
 __END__
@@ -35,7 +48,7 @@ Pod::Elemental::Node - a thing with Pod::Elemental::Nodes as children
 
 =head1 VERSION
 
-version 0.092900
+version 0.092901
 
 =head1 ATTRIBUTES
 
